package com.huiju.estateagents.job;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.HelpActivity;
import com.huiju.estateagents.entity.TaBuildingDynamic;
import com.huiju.estateagents.entity.TaShareActivity;
import com.huiju.estateagents.service.*;
import io.swagger.models.auth.In;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * @author admin
 * @Title: JudglActivityTimeJob
 * @Description: TODO
 * @date 2019/10/21
 */
@Component
@Configuration
@EnableScheduling
public class JudglActivityTimeJob extends BaseController {

    @Autowired
    private ITaBuildingDynamicService iTaBuildingDynamicService;

    @Autowired
    private ITaShareActivityService iTaShareActivityService;

    @Autowired
    private IHelpActivityService iHelpActivityService;

    @Autowired
    private ITaShareRecordService iTaShareRecordService;

    @Autowired
    private ITaShareChildRecordService iTaShareChildRecordService;

    @Autowired
    private IHelpInitiateRecordService iHelpInitiateRecordService;

    @Autowired
    private IHelpRecordService iHelpRecordService;

    /**
     * 开启定时任务，每天12：30执行
     */
    @Scheduled(cron = "* 30 00 * * ?")
//    @Scheduled(cron = "0/5 * * * * ?")
    private void configureTasks() {

        //活动列表
        QueryWrapper<TaBuildingDynamic> buildingDynamicQueryWrapper = new QueryWrapper<>();
        buildingDynamicQueryWrapper.ne("activity_status", "2");
        List<TaBuildingDynamic> taBuildingDynamics = iTaBuildingDynamicService.list(buildingDynamicQueryWrapper);

        //拼团活动列表
        QueryWrapper<TaShareActivity> shareActivityQueryWrapper = new QueryWrapper<>();
        shareActivityQueryWrapper.ne("activity_status", "2");
        List<TaShareActivity> taShareActivities = iTaShareActivityService.list(shareActivityQueryWrapper);

        //助力活动列表
        QueryWrapper<HelpActivity> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.ne("activity_status", "2");
        List<HelpActivity> helpActivities = iHelpActivityService.list(activityQueryWrapper);

        LocalDateTime nowTime = LocalDateTime.now();

        List<String> startActivityIds = new ArrayList<>();
        List<String> endActivityIds = new ArrayList<>();
        for (TaBuildingDynamic taBuildingDynamic : taBuildingDynamics){
            LocalDateTime startTime = taBuildingDynamic.getStartDate();
            LocalDateTime endTime = taBuildingDynamic.getEndDate();
            if (nowTime.isAfter(startTime) && endTime.isAfter(nowTime)){
                startActivityIds.add(taBuildingDynamic.getDynamicId());
            }
            if (nowTime.isAfter(endTime)){
                endActivityIds.add(taBuildingDynamic.getDynamicId());
            }
        }
        iTaBuildingDynamicService.updateUnStartActivity(startActivityIds);
        iTaBuildingDynamicService.updateEndActivity(endActivityIds);


        List<Integer> startGroupActivityIds = new ArrayList<>();
        List<Integer> endGroupActivityIds = new ArrayList<>();
        for (TaShareActivity taShareActivity : taShareActivities){
            LocalDateTime startTime = taShareActivity.getStartTime();
            LocalDateTime endTime = taShareActivity.getEndTime();
            if (nowTime.isAfter(startTime) && endTime.isAfter(nowTime)){
                startGroupActivityIds.add(taShareActivity.getGroupActicityId());
            }
            if (nowTime.isAfter(endTime)){
                endGroupActivityIds.add(taShareActivity.getGroupActicityId());
            }
        }
        iTaShareActivityService.updateUnStartActivity(startGroupActivityIds);
        iTaShareActivityService.updateEndActivity(endGroupActivityIds);
        iTaShareRecordService.updateEndActivity(endGroupActivityIds);
        iTaShareChildRecordService.updateEndActivity(endGroupActivityIds);

        List<Integer> startHelpActivityIds = new ArrayList<>();
        List<Integer> endHelpActivityIds = new ArrayList<>();
        for (HelpActivity helpActivity : helpActivities){
            LocalDateTime startTime = helpActivity.getStartDate();
            LocalDateTime endTime = helpActivity.getEndDate();
            if (nowTime.isAfter(startTime) && endTime.isAfter(nowTime)){
                startHelpActivityIds.add(helpActivity.getHelpActivityId());
            }
            if (nowTime.isAfter(endTime)){
                endHelpActivityIds.add(helpActivity.getHelpActivityId());
            }
        }
        iHelpActivityService.updateUnStartActivity(startHelpActivityIds);
        iHelpActivityService.updateEndActivity(endHelpActivityIds);
        iHelpInitiateRecordService.updateEndActivity(endHelpActivityIds);
    }

}